==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/CheckForUpdates/ts/CheckForUpdates_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CheckForUpdates</name>
    <message>
        <location filename="../CheckForUpdates.js" line="+62"/>
        <location filename="../CheckForUpdatesDialog.ui" line="+14"/>
        <source>Checking for Updates...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Sprawdzanie aktualizacji ...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Version information not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>No connection to server or file not found. Please try again later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about:blank</source>
        <translatorcomment>--google--
&lt;title&gt;o:pusty&lt;/title&gt;</translatorcomment>
        <translation type="obsolete">about: blank</translation>
    </message>
    <message>
        <location filename="../CheckForUpdatesDialog.ui" line="+53"/>
        <source>Automatically check for updates</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Automatycznie sprawdzać aktualizacje</translation>
    </message>
    <message>
        <location filename="../CheckForUpdatesInit.js" line="+6"/>
        <source>Check for &amp;Updates...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Sprawdź aktualizacje ...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/CheckForUpdates/ts/CheckForUpdates_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CheckForUpdates</name>
    <message>
        <location filename="../CheckForUpdates.js" line="+62"/>
        <location filename="../CheckForUpdatesDialog.ui" line="+14"/>
        <source>Checking for Updates...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Sprawdzanie uaktualnień...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Version information not found.</source>
        <translation>Nie odnaleziono informacji o wersji.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>No connection to server or file not found. Please try again later.</source>
        <translation>Brak połączenia z serwerem lub nie odnaleziono pliku. Proszę spróbować ponownie później.</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translatorcomment>--google--
&lt;title&gt;o:pusty&lt;/title&gt;</translatorcomment>
        <translation type="obsolete">about: blank</translation>
    </message>
    <message>
        <location filename="../CheckForUpdatesDialog.ui" line="+53"/>
        <source>Automatically check for updates</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Automatyczne sprawdzanie uaktualnień</translation>
    </message>
    <message>
        <location filename="../CheckForUpdatesInit.js" line="+6"/>
        <source>Check for &amp;Updates...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Sprawdź &amp;uaktualnienia...</translation>
    </message>
</context>
</TS>
